<?php


namespace App\Exports;
use App\Models\Customer;
use App\Services\Core\Customer\CustomerService;
use Illuminate\Support\Facades\Hash;
use Maatwebsite\Excel\Concerns\ToModel;
use Maatwebsite\Excel\Concerns\ToCollection;
use Maatwebsite\Excel\Concerns\WithChunkReading;


class ClientImport  implements ToModel,WithChunkReading
{
    protected $customerService;


    public function __construct(CustomerService $customerService)
    {
        $this->customerService = $customerService;
    }
    public function model(array $row)
    {
        $idNumber = $row['id_number'] ?? '';
        $kraPin = $row['kra_pin'] ?? '';
        $gender = $row['gender'] ?? '';
        $dob = $row['dob'] ?? '';
        $email = $row['email'] ?? '';
        $userId = $row['user_id'] ?? '';
        $postalCode = $row['postal_code'] ?? '';
        $countryId = $row['country_id'] ?? '';
        $phone = $row['phone'] ?? '';
        $boxAddress = $row['box_address'] ?? '';
        $locationAddress = $row['location_address'] ?? '';
        $bankName = $row['bank_name'] ?? '';
        $bankBranch = $row['bank_branch'] ?? '';
        $accountName = $row['account_name'] ?? '';
        $accountNo = $row['account_no'] ?? '';
        $currency = $row['currency'] ?? '';
        $swiftCode = $row['swift_code'] ?? '';
        $bankSlip = $row['bank_slip'] ?? '';
        $kinName = $row['kin_name'] ?? '';
        $kinId = $row['kin_id'] ?? '';
        $kinKraPin = $row['kin_kra_pin'] ?? '';
        $kinGender = $row['kin_gender'] ?? '';
        $kinEmail = $row['kin_email'] ?? '';
        $kinPhone = $row['kin_phone'] ?? '';
        $kinBoxAddress = $row['kin_box_address'] ?? '';
        $kinLocationAddress = $row['kin_location_address'] ?? '';

        // Generate a random password
        $password = $this->customerService->randomPassword();

        // Set validation rules for the imported data (you may need to customize this)
        // $this->customerService->setImportValidation($row);

        // Create a new customer with the imported data
        $customer = new Customer([
            'id_number' => $idNumber,
            'kra_pin' => $kraPin,
            'gender' => $gender,
            'dob' => $dob,
            'email' => $email,
            'user_id' => $userId,
            'postal_code' => $postalCode,
            'country_id' => $countryId,
            'phone' => $phone,
            'box_address' => $boxAddress,
            'location_address' => $locationAddress,
            'bank_name' => $bankName,
            'bank_branch' => $bankBranch,
            'account_name' => $accountName,
            'account_no' => $accountNo,
            'currency' => $currency,
            'swift_code' => $swiftCode,
            'bank_slip' => $bankSlip,
            'kin_name' => $kinName,
            'kin_id' => $kinId,
            'kin_kra_pin' => $kinKraPin,
            'kin_gender' => $kinGender,
            'kin_email' => $kinEmail,
            'kin_phone' => $kinPhone,
            'kin_box_address' => $kinBoxAddress,
            'kin_location_address' => $kinLocationAddress,
        ]);

        $this->customerService
            ->setModel($customer)
            ->setUserValidation()
            ->saveUser($password)
            ->roleAssign()
            ->clientStore()
            ->profileStore()
            ->clientInvitationMail($password);
        return $customer;
    }

    public function chunkSize(): int
    {
        return 1000;
    }

}