<?php


namespace App\Exports;


use App\Filters\Patch\Rewards\RewardsFilter;
use App\Models\Commission;
use Maatwebsite\Excel\Concerns\FromCollection;
use Maatwebsite\Excel\Concerns\WithHeadings;

class CommissionExport  implements FromCollection, WithHeadings
{
    protected $filters;

    public function __construct(RewardsFilter $filters)
    {
        $this->filters = $filters;
    }
    public function headings(): array
    {
        return [
            "Commission Date",
            "Project",
            "Unit Name",
            "Unit Cost",
            "Commission Amount",
            "Total Paid",
            "Agent Name",
            "Account Name",
            "Account Number",
            "Bank Name",
            "Bank Branch",
            "Swift",
            "Payment Ref No",
            "Payment Date"
        ];
    }

    public function collection()
    {
        $data = Commission::filters($this->filters)
            ->with([
                'property:id,project_name',
                'unit:id,unit_name,sale_amount,square_foot,unit_floor',
                'agent:id,first_name,last_name',
                'agentDetails',
                'invoice'
            ])
            ->get();

        return $data->map(function ($row) {
            return [
                "Commission Date"=> date_format($row->created_at, 'Y-m-d'),
                "Project Name" => @$row->property->project_name,
                "Unit Name" => @$row->unit->unit_name,
                "Unit Cost" => @$row->unit->sale_amount,
                "Commission Amount" => @$row->commission_amount,
                "Total Paid" => @$row->invoice->received_amount,
                "Agent Name"=> @$row->agent->full_name,
                "Account Name" => @$row->agentDetails->account_name,
                "Account Number" => @$row->agentDetails->account_no,
                "Bank Name" => @$row->agentDetails->bank_name,
                "Bank Branch" =>  @$row->agentDetails->bank_branch,
                "Swift"=>  @$row->agentDetails->swift_code,
                "Payment Ref No"=>@$row->reference_no,
                "Payment Date"=>@$row->payment_date
                //"Payment Date"=> if$row->payment_date) ? date_format($row->payment_date, 'Y-m-d'): ''
            ];
        });
    }

}