<?php


namespace App\Filters\Patch\Invoice;


use App\Filters\Patch\Traits\SelectedFilterTraits;
use App\Filters\Core\BaseFilter;
use App\Filters\Patch\Traits\AgentFilterTraits;
use App\Filters\Patch\Traits\ClientFilterTraits;
use App\Filters\Patch\Traits\InvoiceNumberFilterTrait;
use App\Filters\Patch\Traits\StatusFilterTrait;
use App\Models\Patch\Traits\IndividualAgentTrait;
use App\Models\Patch\Traits\IndividualClientTrait;
use Illuminate\Database\Eloquent\Builder;

class InvoiceFilter  extends BaseFilter
{
    use
        StatusFilterTrait,
        ClientFilterTraits,
        AgentFilterTraits,
        InvoiceNumberFilterTrait,
        IndividualClientTrait,
        IndividualAgentTrait,
        SelectedFilterTraits;


    public function date($date = null)
    {
        $date = json_decode(htmlspecialchars_decode($date), true);
        $this->builder->when($date, function (Builder $builder) use ($date) {
            $builder->whereBetween(\DB::raw('DATE(date)'), array_values($date));
        });
    }

    public function due($dueDate = null)
    {
        $dueDate = json_decode(htmlspecialchars_decode($dueDate), true);
        $this->builder->when($dueDate, function (Builder $builder) use ($dueDate) {
            $builder->whereBetween(\DB::raw('DATE(due_date)'), array_values($dueDate));
        });
    }

    public function amountRange($value = null)
    {
        $value = json_decode(htmlspecialchars_decode($value), true);
        return $this->builder->when($value, function (Builder $builder) use ($value) {
            $builder->whereBetween('sub_total', array_values($value));
        });

    }

    public function paidRange($value = null)
    {
        $value = json_decode(htmlspecialchars_decode($value), true);
        return $this->builder->when($value, function (Builder $builder) use ($value) {
            $builder->whereBetween('received_amount', array_values($value));
        });
    }

    public function dueRange($value = null)
    {
        $value = json_decode(htmlspecialchars_decode($value), true);
        return $this->builder->when($value, function (Builder $builder) use ($value) {
            $builder->whereBetween('due_amount', array_values($value));
        });
    }

    public function units($ids = null){
        if ($ids){
            $value = explode(',', $ids);
            return $this->builder->when($value, function (Builder $query) use ($value) {
                $query->whereHas('unit', function (Builder $query) use ($value) {
                    $query->whereIn('unit_id', $value);
                });
            });
        }
    }

    public function properties($ids = null){
        if ($ids){
            $value = explode(',', $ids);
            return $this->builder->when($value, function (Builder $query) use ($value) {
                $query->whereHas('unit', function (Builder $query) use ($value) {
                    $query->whereIn('property_id', $value);
                });
            });
        }
    }

}
