<?php

namespace App\Http\Controllers\App\Agent;
use App\Exceptions\GeneralException;
use App\Exports\AgentsExport;
use App\Filters\Patch\Agent\AgentFilter;
use App\Http\Controllers\Controller;
use App\Models\Agent;
use App\Services\Core\Agent\AgentService;
use Illuminate\Foundation\Auth\User;
use Illuminate\Http\Request;

use Exception;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Maatwebsite\Excel\Facades\Excel;

class AgentController extends Controller
{

    public function __construct(AgentService $service, AgentFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {

        $user = Auth::user();

        $query = Agent::with([
                'country:id,name',
                'user' => function ($query) {
                    $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
                }])
            ->filters($this->filter);
            if (!$user->isAppAdmin()) {
                $query->where('created_by', $user->id);
            }

       return $query->orderBy('id', request()->get('orderBy'))
        ->paginate(request('per_page', 10));
    }




    public function store(Request $request)
    {
        $password = $this->service->randomPassword();
        $this->service
            ->setValidation()
            ->setUserValidation()
            ->saveUser($password)
            ->roleAssign()
            ->agentStore()
            ->profileStore()
            ->agentInvitationMail($password);

        return created_responses('agents');
    }


    public function show($id)
    {
        return $this->service->with([
            'country:id,name',
            'user' => function ($query) {
                $query->with('profilePicture', 'profile:id,user_id,address,contact');
            }])->find($id);
    }

    public function update(Request $request)
    {
        // Validation rules
        $rules = [
            'full_name' => 'required|string|max:255',
            'email' => 'required|email|max:255|unique:users,email,' . $request->user_id,
            'user_id' => 'required|exists:users,id',
            'id' => 'required|exists:agents,id', // Ensure agent ID exists
        ];

        $validator = Validator::make($request->all(), $rules);

        if ($validator->fails()) {
            return response()->json(['errors' => $validator->errors()], 422);
        }

        try {
            // Begin transaction
            DB::beginTransaction();

            // Log initial details
            \Log::info("Agent and User details before update", [
                'agent_id' => $request->input('id'),
                'user_id' => $request->input('user_id')
            ]);

            // Update the user information
            DB::table('users')
                ->where('id', $request->input('user_id'))
                ->update([
                    'first_name' => $request->input('first_name'),
                    'last_name' => $request->input('last_name'),
                    'email' => $request->input('email'),
                ]);

            // Update the agent information
            DB::table('agents')
                ->where('id', $request->input('id'))
                ->update([
                    'full_name' => $request->input('full_name'),
                    'user_id' => $request->input('user_id'),
                    'kra_pin' => $request->input('kra_pin'),
                    'created_by' => $request->input('created_by'),
                    'gender' => $request->input('gender'),
                    'phone' => $request->input('phone'),
                    'postal_code' => $request->input('postal_code'),
                    'sales_agent_code' => $request->input('sales_agent_code'),
                    'country_id' => $request->input('country_id'),
                    'bank_name' => $request->input('bank_name'),
                    'bank_branch' => $request->input('bank_branch'),
                    'account_name' => $request->input('account_name'),
                    'account_no' => $request->input('account_no'),
                    'currency' => $request->input('currency'),
                    'swift_code' => $request->input('swift_code'),
                ]);

            // Commit transaction if updates are successful
            DB::commit();

            // Log successful update
            \Log::info("Agent and user information updated successfully.", [
                'agent_id' => $request->input('id'),
                'user_id' => $request->input('user_id')
            ]);

            return updated_responses('crud_response');
        } catch (\Exception $e) {
            // Rollback transaction and log error
            DB::rollBack();
            \Log::error("Update failed: " . $e->getMessage(), [
                'agent_id' => $request->input('id'),
                'user_id' => $request->input('user_id')
            ]);

            return updated_responses('crud_response');
        }
    }


//    public function update(Request $request, Agent $agent)
//    {
//
//        // Validation rules
//        $rules = [
//            'full_name' => 'required|string|max:255',
//            'email' => 'required|email|max:255|unique:users,email,' . $request->user_id,
//            'user_id' => 'required|exists:users,id',
//        ];
//
//        $validator = Validator::make($request->all(), $rules);
//
//        if ($validator->fails()) {
//            return response()->json(['errors' => $validator->errors()], 422);
//        }
//
//        // Find the agent
//        $agent = Agent::findOrFail($request->input('id'));
//
//        \Log::info("Email sent to: {$agent}");
//
//
//        // Find the user
//        $user = User::findOrFail($request->input('user_id'));
//
//        \Log::info("Email sent to: {$user}");
//
//
//        // Begin transaction
//
//        DB::beginTransaction();
//
//        try {
//            // Update the user
//            $user->update([
//                'first_name' => $request->input('first_name'),
//                'last_name' => $request->input('last_name'),
//                'email' => $request->input('email'),
//            ]);
//
//            // Update the agent
//
//            $agent->update([
//                'full_name' => $request->input('full_name'),
//                'user_id' => $request->input('user_id'),
//                'kra_pin' => $request->input('kra_pin'),
//                'created_by' => $request->input('created_by'),
//                'gender' => $request->input('gender'),
//                'phone' => $request->input('phone'),
//                'postal_code' => $request->input('postal_code'),
//                'sales_agent_code' => $request->input('sales_agent_code'),
//                'country_id' => $request->input('country_id'),
//                'bank_name' => $request->input('bank_name'),
//                'bank_branch' => $request->input('bank_branch'),
//                'account_name' => $request->input('account_name'),
//                'account_no' => $request->input('account_no'),
//                'currency' => $request->input('currency'),
//                'swift_code' => $request->input('swift_code'),
//            ]);
//
//            // Commit transaction
//            DB::commit();
//
//            return updated_responses('crud_response');
//        } catch (\Exception $e) {
//            // Rollback transaction
//            DB::rollBack();
//
//            return updated_responses('crud_response');
//        }
//
//
//    }

    public function exportAgents()
    {
        return Excel::download(new AgentsExport(), 'agents.csv', \Maatwebsite\Excel\Excel::CSV);
    }



    public function destroy(Agent $client)
    {
        $invoiceExist = $client->load(['user' => function ($query) {
            $query->withCount('invoices');
        }]);

        if (optional($invoiceExist->user)->invoices_count > 0)
            throw new GeneralException(trans('default.this_client_has_an_invoice_record'));

        $this->service
            ->setModel($client)
            ->userDelete()
            ->delete();

        return deleted_responses('agents');
    }
}
