<?php


namespace App\Http\Controllers\App\AgentLeed;


use App\Filters\Patch\Units\UnitBookingFilter;
use App\Http\Controllers\Controller;
use App\Models\Unit;
use App\Models\UnitBooking;
use App\Services\Patch\Liason\UnitBookingService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;

class OfferLetterController  extends Controller
{
    public function __construct(UnitBookingService $service, UnitBookingFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;


    }

    public function index()
    {
        $user = Auth::user();

        $query = UnitBooking::with([
            'property:id,project_name',
            'unit',
            'status:id,name,class',
            'payment_status:id,name,class',
            'document_status:id,name,class',

            'user' => function ($query) {
                $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
            },
            'plan',
            'customer',

        ])->where('payment_status_id',15)
            ->whereHas('unit', function ($q) {
                // Ensure amount in UnitBooking is at least 2000

                   $q->whereRaw('amount < 0.25 * sale_amount');

            })

            ->filters($this->filter);

        if (!$user->isAppAdmin()) {
            $query->where('user_id', $user->id);
        }

        return $query->orderBy('id', request()->get('orderBy'))
            ->paginate(request('per_page', 10));

    }

    public function show($id)
    {
        return $this->service->with(['status:id,name,class','property','unit', 'plan',
            'customer',])->find($id);
    }

    public function store(Request $request)
    {
        $requestData = $request->only(['property_id', 'unit_id', 'user_id', 'plan_id','customer_id','posting_date',
            'document_date','installment_date','payment_start_date',     'reference_number','payment_mode', 'amount']);

        $requestData['user_id'] = Auth::id();
        $this->service
//            ->setValidation()
            ->setAttributes($requestData)
            ->save();

        $unitIdToUpdate = $request->input('unit_id');
        $newStatusId = 16;
        $unit = Unit::findOrFail($unitIdToUpdate);
        $unit->status_id = $newStatusId;
        $unit->save();

        return created_responses('bookings');
    }

    public function update(Request $request, UnitBooking $unit)
    {
        $this->service
            ->setModel($unit)
            ->setValidation()
            ->setAttributes($request->all())
            ->update();
        return updated_responses('bookings');

    }

    public function destroy(UnitBooking $unit)
    {
        $this->service
            ->setModel($unit)
            ->delete();
        return deleted_responses('bookings');

    }



}