<?php


namespace App\Http\Controllers\App\Customer;


use App\Filters\Patch\TitleDeed\TitleDeedFilter;
use App\Http\Controllers\Controller;
use App\Models\Agent;
use App\Models\Customer;
use App\Models\KycDocument;
use App\Services\Patch\Liason\KycService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use mysql_xdevapi\Exception;

class KyCustomerController  extends Controller
{

    public function __construct(KycService $service, TitleDeedFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;

    }

    public function index()
    {
        if (\Request::exists('all')) {
            return $this->service->select('id', 'name')->get();
        }


        $user = Auth::user();

        $query = $this->service
            ->filters($this->filter)
            ->with([
                'customer',
                'attachment',
                'user' => function ($query) {
                    $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
                }
            ]);

        if (!$user->isAppAdmin()) {
            $query->where('user_id', $user->id); // Limit data to the current user's records
        }



        return $query->orderByDesc('id')
            ->paginate(request('per_page', 15));
    }

    public function customerKyc($clientId)
    {
        try{
            if (\Request::exists('all')) {
                return $this->service->select('id', 'name')->get();
            }

            $user = Auth::user();

            $query = $this->service
                ->filters($this->filter)
                ->with([
                    //'customer',
                    'attachment',
                    'user' => function ($query) {
                        $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
                    }
                ]);

            if (!$user->isAppAdmin()) {
                $query->where('user_id', $user->id); // Limit data to the current user's records
            }

            if ($clientId){
                $query->whereHas('customer', function ($q) use ($clientId) {
                    $q->where('id', $clientId);
                });
            }

            return $query->orderByDesc('id')
                ->paginate(request('per_page', 10));
        }
        catch (Exception $e){
            \Log::error('Error in customerKyc:', ['message' => $e->getMessage(), 'trace' => $e->getTraceAsString()]);

            return response()->json([
                'error' => 'An error occurred while processing your request.',
                'message' => $e->getMessage()
            ], 500);
        }

    }

    public function agentKyc($agentId)
    {
        try{
            if (\Request::exists('all')) {
                return $this->service->select('id', 'name')->get();
            }

            $user = Auth::user();

            $query = $this->service
                ->filters($this->filter)
                ->with([
                    //'customer',
                    'attachment',
                    'user' => function ($query) {
                        $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
                    }
                ]);

            if (!$user->isAppAdmin()) {
                $query->where('user_id', $user->id); // Limit data to the current user's records
            }

            if ($agentId){
                $query->whereHas('agent', function ($q) use ($agentId) {
                    $q->where('id', $agentId);
                });
            }

            return $query->orderByDesc('id')
                ->paginate(request('per_page', 10));
        }
        catch (Exception $e){
            \Log::error('Error in customerKyc:', ['message' => $e->getMessage(), 'trace' => $e->getTraceAsString()]);

            return response()->json([
                'error' => 'An error occurred while processing your request.',
                'message' => $e->getMessage()
            ], 500);
        }

    }

    public function show($id)
    {
        return $this->service->with('customer','attachment','user')->find($id);
    }


    public function store(Request $request)
    {
        if ($request->user_type == 'AGENT'){
            $customerUserId = Agent::where('id', $request->customer_id)->value('user_id');
        }
        else{
            $customerUserId = Customer::where('id', $request->customer_id)->value('user_id');
        }

        $requestData = $request->except('attachment');
        $requestData['user_id'] = Auth::id();
        $requestData['customer_id'] = $customerUserId;

        $this->service
            ->checkValidation()
            ->setAttributes($requestData)
            ->save();

        $this->service->when($request->has('attachment'), fn(KycService $service) => $service->saveAttachment($request->attachment));

        return created_responses('crud_response');

    }

    public function update(Request $request,  $id)
    {

        $kyc = KycDocument::findOrFail($id); // Throws an error if not found


        $this->service
            ->setModel($kyc)
            ->checkValidation()
            ->setAttributes($request->only(
                'name',
                'description'))
            ->update();

        $this->service->when($request->has('attachment'), fn(KycService $service) => $service->saveAttachment($request->attachment));

        return updated_responses('crud_response');
    }

    public function destroy($id)
    {

        $kyc = KycDocument::findOrFail($id); // Throws an error if not found

        $this->service
            ->setModel($kyc)
            ->deleteAttachment()
            ->deleteAttachmentData()
            ->delete();
        return deleted_responses('crud_response');
    }



}