<?php

namespace App\Http\Controllers\App\Leads;
use App\Filters\Patch\Leads\PatchLeadFilter;
use App\Http\Controllers\Controller;

use App\Models\Leads;
use App\Services\Patch\Liason\LeadService;
use Illuminate\Http\Request;

class LeadsController extends Controller
{

    public function __construct(LeadService $service, PatchLeadFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }


    public function index()
    {
        if (\Request::exists('all')) {
            return $this->service->select('id')->get();
        }
        $orderBy = request()->get('orderBy', 'asc'); // Default to 'asc' if no orderBy parameter is provided

        if (!in_array($orderBy, ['asc', 'desc'])) {
            $orderBy = 'asc'; // Set to default 'asc' if provided orderBy value is invalid
        }
        return $this->service
            ->with('property:id,project_name,property_code,property_name', 'agent:id,sales_agent_code','customer:id')
            ->filters($this->filter)
            ->orderBy('id', $orderBy)
            ->paginate(request('per_page', 10));

    }


    public function store(Request $request)
    {
        $this->service
           // ->setValidation()
            ->setAttributes($request->all())
            ->save();

        return created_responses('leads');
    }


    public function show($id)
    {
        return $this->service->with('property','agent','customer')->find($id);
    }


    public function update(Request $request, Leads $leads)
    {
        $this->service
            ->setModel($leads)
            ->setValidation()
            ->setAttributes($request->only(
                'unit_no',
                'lead_no',
                'posting_date',
                'document_date',
                'payment_plan',
                'property_id',
                'customer_id',
                'agent_id',
                'installment_date',
                'sale_type_id',
                'agent_commission_value',
                'agent_commission_type',
                'plots_allocated',
                'booking_reference',
                'posted',
                'max_installment',
                'no_of_installments',
                'total_cost',
                'total_cost',
                'total_sales',
                'selling_price',
                'payment_start_date',
            ))
            ->update();

        return updated_responses('leads');
    }


    public function destroy(Leads $leads)
    {
        $this->service
            ->setModel($leads)
            ->delete();
        return deleted_responses('leads');
    }
}
