<?php


namespace App\Http\Controllers\App\Payment\Finance;


use App\Filters\Patch\Units\UnitBookingFilter;
use App\Http\Controllers\Controller;
use App\Mail\Patch\LegalReminderNotification;
use App\Models\Commission;
use App\Models\Invoice;
use App\Models\Payment;
use App\Models\Property;
use App\Models\Unit;
use App\Models\UnitBooking;
use App\Services\Patch\Liason\UnitBookingService;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Mail;
use Mockery\Exception;

class OfferLetterPaymentController  extends Controller
{
    public function __construct(UnitBookingService $service, UnitBookingFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;


    }

    public function index()
    {
        $user = Auth::user();

        $query = UnitBooking::with([
            'property:id,project_name',
            'unit',
            'status:id,name,class',
            'payment_status:id,name,class',
            'user' => function ($query) {
                $query->with('profilePicture', 'status:id,name,class', 'profile:id,user_id,address,contact');
            },
            'plan',
            'customer',

        ])->where('payment_status_id',16)
            ->whereHas('unit', function ($q) {
                $q->whereRaw('amount < 0.25 * sale_amount');

            })

            ->filters($this->filter);

        return $query->orderBy('id', request()->get('orderBy'))
            ->paginate(request('per_page', 10));

    }

    public function show($id)
    {
        return $this->service->with(['status:id,name,class','property','unit', 'plan',
            'customer',])->find($id);
    }

    public function store(Request $request)
    {
        $requestData = $request->only(['property_id', 'unit_id', 'user_id', 'plan_id','customer_id','posting_date',
            'document_date','installment_date','payment_start_date',     'reference_number','payment_mode', 'amount']);

        $requestData['user_id'] = Auth::id();
        $this->service
//            ->setValidation()
            ->setAttributes($requestData)
            ->save();

        $unitIdToUpdate = $request->input('unit_id');
        $newStatusId = 16;
        $unit = Unit::findOrFail($unitIdToUpdate);
        $unit->status_id = $newStatusId;
        $unit->save();

        return created_responses('bookings');
    }


    public function update(UnitBooking $unit,$id)
    {
        try{
            DB::beginTransaction();

            $bookingModel = $this->service->with('unit')->find($id);
            $sendLegalEmail = false;
            $documentType = '';

            if ($bookingModel){
                $this->service->where('id', $id)->update(\request()->only('payment_status_id'));

                $unit_id=$bookingModel->unit_id;

                $invoice = Invoice::where('unit_id', $unit_id)->first();

                $invoiceId = $invoice->id;


                $invoice = Payment::where('invoice_id', $invoiceId)->firstOrFail();

                $invoice->payment_status_id = 15;

                $invoice->save();



                // Check commission logic
                $property = Property::where('id', $bookingModel->unit['property_id'])->first();
                if ($property && $property->allow_commission == 1) {
                    //should be more or equal to 10%
                    $targetAmountForSales = 0.1 * (double)$bookingModel->unit['sale_amount'];
                    if ($bookingModel->amount >= $targetAmountForSales) {
                        // Check if commission already exists
                        $commission = Commission::where('unit_id', $bookingModel->unit_id)->first();
                        if (!$commission) {
                            $amount = $property->commission / 100 * (double)$bookingModel->unit['sale_amount'];
                            $commission = new Commission();
                            $commission->property_id = $bookingModel->unit['property_id'];
                            $commission->unit_id = $bookingModel->unit['id'];
                            $commission->commission_amount = $amount;
                            $commission->company_share_amount = $amount;
                            $commission->invoice_id = $bookingModel->invoice_id;
                            $commission->agent_id = $bookingModel->user_id;
                            $commission->payment_status_id = 30; //pending
                            $commission->save();
                        }
                    }
                }

                //check what stage the amount is offer letter 10%, sale agreement 0.25%,
                // title deed 100% to send notification

                $targetOfferLetter = 0.1 * (double)$bookingModel->unit['sale_amount'];
                $targetSaleAgreement = 0.25 * (double)$bookingModel->unit['sale_amount'];
                $titleDeed = (double)$bookingModel->unit['sale_amount'];

                //if upload is pending
                if ($bookingModel->document_status_id == 23){
                    //reminder to prepare offer letter
                    if ($bookingModel->amount >= $targetOfferLetter && $bookingModel->amount < $targetSaleAgreement) {
                        $sendLegalEmail = true;
                        $documentType = 'Offer Letter';
                    }
                    else
                        if ($bookingModel->amount >= $targetSaleAgreement && $bookingModel->amount != $titleDeed) {
                            $sendLegalEmail = true;
                            $documentType = 'Sale Agreement';
                        }
                        else if ($bookingModel->amount >= $titleDeed){
                            $sendLegalEmail = true;
                            $documentType = "Title Deed";
                        }
                }

                // Commit the transaction
                DB::commit();

                if ($sendLegalEmail){
                    $legalEmail = env('LEGAL_REMINDER_EMAIL', 'legal@patchafrica.net');
                    Mail::to($legalEmail)->send(new LegalReminderNotification($bookingModel, $documentType));
                }

                return updated_responses('crud_response');
            }
        }
        catch (Exception $exception){
            // Rollback the transaction if an error occurs
            DB::rollBack();
            echo $exception;
        }
    }

    public function destroy(UnitBooking $unit)
    {
        $this->service
            ->setModel($unit)
            ->delete();
        return deleted_responses('bookings');

    }

}