<?php

namespace App\Http\Controllers\App\Properties;
use App\Filters\Patch\Property\PropertyUnitFilter;
use App\Http\Controllers\Controller;
use App\Http\Requests\UnitRequest;
use App\Models\ReservedUnitPayment;
use App\Models\Unit;
use App\Services\Core\Property\PropertyUnitService;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\DB;
use mysql_xdevapi\Exception;


class PropertyUnitsController extends Controller
{


    public function __construct(PropertyUnitService $service, PropertyUnitFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {
        try{
            if (\Request::exists('all')) {
                return $this->service->select('id', 'unit_name', 'sale_amount')->get();
            }
            $orderBy = request()->get('orderBy', 'asc');

            if (!in_array($orderBy, ['asc', 'desc'])) {
                $orderBy = 'asc';
            }
            return $this->service
                ->with(['status:id,name,class', 'property','unit'])
                ->where('status_id',10)
                ->filters($this->filter)
                ->orderBy('id', $orderBy)
                ->paginate(request('per_page', 10));
        }
        catch (\Exception $exception){
            echo $exception->getMessage();
        }

    }

    public function show($id)
    {
        return $this->service->with(['status:id,name,class','property','unit'])->find($id);
    }


    public function update(UnitRequest $request, Unit $unit)
    {
        DB::beginTransaction();

        try {

            $unit['status_id']  = 12;
            $unit->save();

            ReservedUnitPayment::updateOrCreate(
                ['unit_id' => $unit->id],
                [
                    'created_by' => Auth::id(),
                    'status_id' => 12,
                    'payment_status_id' => 16,
                    'property_id' => $request->input('property_id'),
                    'note' => $request->input('note'),
                    'amount' => $request->input('amount'),
                    'reference_number' => $request->input('reference_number'),
                    'payment_mode' => $request->input('payment_mode'),
                    'client_name' => $request->input('client_name'),
                    'email' => $request->input('email'),
                    'phone' => $request->input('phone'),
                ]
            );

            DB::commit();
            return updated_responses('crud_response');

        } catch (\Exception $exception) {
            DB::rollBack();
            \Log::error('Error updating unit: ' . $exception->getMessage());
            return response()->json(['error' => 'Something went wrong.'.$exception->getMessage()], 500);
        }

    }


    public function destroy(Unit $unit)
    {
        $this->service
            ->setModel($unit)
            ->unlinkImage()
            ->deleteFileDatabase()
            ->delete();
        return deleted_responses('units');

    }



}
