<?php


namespace App\Http\Controllers\App\Rewards;


use App\Exports\CommissionExport;
use App\Filters\Patch\Rewards\RewardsFilter;
use App\Http\Controllers\Controller;
use App\Models\Commission;
use App\Services\Core\Rewards\CommissionService;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Maatwebsite\Excel\Facades\Excel;
use Mockery\Exception;
use Illuminate\Http\Request;

class CommissionController  extends Controller
{

    public function __construct(CommissionService $service, RewardsFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {
        try{
            $user = Auth::user();
            $query = Commission::with([
                'property:id,project_name',
                'unit:id,unit_name,sale_amount,square_foot,unit_floor',
                'agent:id,first_name,last_name',
                'user:id,first_name,last_name',
                'agentDetails',
                'invoice'
            ])->filters($this->filter);

            if (!$user->isAppAdmin() && !$user->hasRole('Finance Admin')) {
                // Restrict agents to their own data
                $query->where('agent_id', $user->id);
            }
            return $query->orderBy('id', request()->get('orderBy'))
                ->paginate(request('per_page', 10));
        }
        catch (Exception $exception){
            echo $exception->getMessage();
        }

    }

    public function update(Request $request, $id){
        try{
            $commissionModel = Commission::findOrFail($id);
            //mark as paid
            $commissionModel['payment_status_id'] = 31;
            $commissionModel['payment_date'] = $request->input('payment_date');
            $commissionModel['reference_no'] = $request->input('reference_number');
            $commissionModel['action_date'] = Carbon::now();
            $commissionModel['action_by'] = Auth::id();
            $commissionModel->save();

            return updated_responses('commissions_paid');

        }
        catch (Exception $exception){

        }
    }

    public function export()
    {
        return Excel::download(new CommissionExport($this->filter), 'commission_statement_report.csv',\Maatwebsite\Excel\Excel::CSV);
    }
}