<?php

namespace App\Http\Controllers\App\TitleDeed;
use App\Exports\TitleExports;
use App\Filters\Patch\TitleDeed\TitleDeedFilter;
use App\Http\Controllers\Controller;

use App\Models\TitleDeed;
use App\Services\Patch\Liason\TitleDeedService;
use Illuminate\Http\Request;
use Maatwebsite\Excel\Excel;


class TitleDeedController extends Controller
{

    public function __construct(TitleDeedService $service, TitleDeedFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;

    }

    public function index()
    {
        if (\Request::exists('all')) {
            return $this->service->select('id', 'name')->get();
        }
        return $this->service
            ->filters($this->filter)
            ->with(['attachment'])
            ->orderByDesc('id')
            ->paginate(\request('per_page', 15));
    }


    public function store(Request $request)
    {
        $this->service
            ->checkValidation()
            ->setAttributes($request->except('attachment'))
            ->save();

        $this->service->when($request->has('attachment'), fn(TitleDeedService $service) => $service->saveAttachment($request->attachment));

        return created_responses('titles');

    }

    public function update(Request $request, TitleDeed $expense)
    {
        $this->service
            ->setModel($expense)
            ->checkValidation()
            ->setAttributes($request->except('attachment'))
            ->save();

        $this->service->when($request->has('attachment'), fn(TitleDeedService $service) => $service->saveAttachment($request->attachment));

        return updated_responses('titles');
    }

    public function destroy(TitleDeed $expense)
    {
        $this->service
            ->setModel($expense)
            ->deleteAttachment()
            ->deleteAttachmentData()
            ->delete();
        return deleted_responses('expense');
    }

    public function expenseExport()
    {
        return Excel::download(new TitleExports(), 'expense.csv', \Maatwebsite\Excel\Excel::CSV);
    }
}
