<?php


namespace App\Http\Controllers\Patch\Liason;


use App\Filters\Patch\Invoice\InvoiceFilter;
use App\Http\Controllers\Controller;
use App\Jobs\InvoiceAttachmentJob;
use App\Models\Invoice;
use App\Models\InvoiceItem;
use App\Services\Patch\Liason\InvoiceService;
use Illuminate\Http\Request;


class InvoiceController  extends Controller
{

    public function __construct(InvoiceService $service, InvoiceFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {
        try {
            if (request()->get('invoice_type')) {
                return $this->service
                    ->where('recurring', 3)
                    ->with([
                        'status:id,name,class',
                        'client:id,first_name,last_name',
                        'recurringCycle:id,name',
                        'unit:id,unit_name,property_id',
                        'unit.property:id,project_name,property_name'
                    ])
                    ->filters($this->filter)
                    ->orderBy('id', request()->get('orderBy'))
                    ->paginate(request('per_page', 10));
            }

            return $this->service
                ->where('recurring', '!=', 3)
                ->with([
                    'status:id,name,class',
                    'client:id,first_name,last_name',
                    'recurringCycle:id,name',
                    'unit:id,unit_name,property_id',
                    'unit.property:id,project_name,property_name'
                ])
                ->filters($this->filter)
                ->orderBy('id', request()->get('orderBy'))
                ->paginate(request('per_page', 10));

        } catch (\Exception $e) {
            \Log::error('Error in index method: ' . $e->getMessage(), [
                'trace' => $e->getTraceAsString(),
                'input' => request()->all(),
            ]);

            // Return a user-friendly error response
            return response()->json([
                'success' => false,
                'message' => 'Something went wrong. Please try again later.',
                'error' => $e->getMessage(), // Optionally include this for debugging in non-production environments
            ], 500);
        }
    }

    public function store(Request $request)
    {
        $invoice = $this->service
            ->setValidation()
            ->setAttributes($request->all())
            ->save();

        $this->service->when($request->has('products'), fn(InvoiceService $service) => $service->invoiceDetails());

        $invoiceInfo = $this->service->loadInvoiceInfo($invoice);

        $this->service
            ->setAttribute('file_path', 'public/pdf/invoice_' . $invoice->id . '.pdf')
            ->pdfGenerate($invoiceInfo);

//        InvoiceAttachmentJob::dispatch($invoiceInfo)->onQueue('high');
        return created_responses('invoices');
    }


    public function show($id)
    {
        return $this->service
            ->with([
                'client.profile', 'createdBy.profile',
                'invoiceDetails' => function ($query) {
                    $query->with(['tax:id,name,value', 'unit'=>function ($customer) {
                        $customer->with('unit:id,unit_name');
                    }]);
                }
            ])->find($id);
    }

    public function update(Request $request, Invoice $invoice)
    {
        $this->service
            ->setModel($invoice)
            ->setValidation()
            ->setAttributes($request->only(
                'client_id',
                'invoice_number',
                'recurring',
                'date',
                'due_date',
                'status_id',
                'recurring_cycle_id',
                'sub_total',
                'discount_type',
                'discount',
                'total',
                'received_amount',
                'due_amount',
                'notes',
                'terms'
            ))
            ->update();
        $this->service->when($request->has('products'), fn(InvoiceService $service) => $service->invoiceDetails());
        return updated_responses('invoices');
    }
    public function destroy(Invoice $invoice)
    {
        $this->service
            ->setModel($invoice)
            ->delete();
        return deleted_responses('invoices');
    }

    public function detailsDelete()
    {
        $invoices = $this->service->find(request('id'));
        $invoices->update(request()->all());
        $invoice = InvoiceItem::where('id', request('invoice_detail_id'))->delete();
        return deleted_responses('leads', ['invoice' => $invoice]);
    }


}
