<?php


namespace App\Http\Controllers\Patch\Liason\Reports;


use App\Exports\ClientStatementExport;
use App\Filters\Patch\Reports\ClientStatementReportFilter;
use App\Http\Controllers\Controller;
use App\Mail\Patch\MonthlyStatementMail;
use App\Models\Payment;
use App\Services\Patch\Liason\ClientStatementReportService;
use Maatwebsite\Excel\Facades\Excel;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Facades\Mail;


class ClientStatementReportController  extends Controller
{
    public function __construct(ClientStatementReportService $service, ClientStatementReportFilter $filter)
    {
        $this->service = $service;
        $this->filter = $filter;
    }

    public function index()
    {
        return $this->service
            ->with('client:id,first_name,last_name', 'status:id,name,class')
            ->filters($this->filter)
            ->paginate(request('per_page', 10));
    }

    public function export()
    {
        return Excel::download(new ClientStatementExport(), 'client_statement_report.csv', \Maatwebsite\Excel\Excel::CSV);
    }

    public function show($id)
    {
        return $this->service
            ->with([
                'client:id,first_name,last_name',
                'unit',
                'invoiceItems' => function ($query) {
                    $query->with('unit');
                }
            ])->find($id);

    }


    public function paymentUnits($id): \Illuminate\Contracts\Pagination\LengthAwarePaginator
    {
        $invoiceId = $this->service->find($id)->id;
        return Payment::with(['paymentMethod'])
            ->where('invoice_id', $invoiceId)
            ->orderBy('id', request()->get('orderBy'))
            ->paginate(request('per_page', 10));
    }

    public function sendMonthlyStatement($id)
    {

        $invoice = $this->service->find($id);
        $client = $invoice->client;

        $payments = Payment::with(['paymentMethod'])
            ->where('invoice_id', $invoice->id)
            ->orderBy('id')
            ->get();

        $pdf = Pdf::loadView('emails.monthly_statement', compact('invoice', 'payments'));

        if ($client && $client->email) {
            Mail::to($client->email)->send(new MonthlyStatementMail($pdf->output(), $invoice, $payments));
        }
    }

}
