<?php

namespace App\Models;

use App\Models\Core\Auth\User;
use App\Models\Core\BaseModel;
use App\Models\Patch\Address\AgentAddress;
use App\Models\Patch\Address\ClientAddress;
use App\Models\Patch\Country\Country;
use App\Models\Patch\Traits\EmailRelationshipTrait;
use App\Models\Patch\Traits\PhoneRelationshipTrait;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;


class Agent extends BaseModel
{
    use HasFactory,
        EmailRelationshipTrait,
        PhoneRelationshipTrait;
    protected $fillable=[
        'user_id',
        'state',
        'kra_pin',
        'created_by',
        'full_name',
        'gender',
        'phone',
        'postal_code',
        'sales_agent_code',
        'country_id',
        'bank_name',
        'bank_branch',
        'account_name',
        'account_no',
        'currency',
        'swift_code',
    ];

    protected $hidden = [
        'created_at',
        'updated_at'
    ];


    public function country(): BelongsTo
    {
        return $this->belongsTo(Country::class);
    }

    public function addresses(): HasMany
    {
        return $this->hasMany(ClientAddress::class);
    }

    public function user(): BelongsTo
    {
        return $this->belongsTo(User::class);
    }

}
