<?php


namespace App\Models;


use App\Models\Core\BaseModel;
use App\Models\Patch\User\User;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class Commission  extends BaseModel
{

    use HasFactory;

    protected $table = 'commissions';

    protected $fillable = ['property_id', 'invoice_id', 'unit_id','agent_id', 'commission_amount', 'company_share_amount', 'reference_number', 'action_by', 'payment_date'];


    public function property()
    {
        return $this->belongsTo(Property::class, 'property_id');
    }

    public function unit()
    {
        return $this->belongsTo(Unit::class, 'unit_id');
    }

    public function invoice(): BelongsTo
    {
        return $this->belongsTo(Invoice::class);
    }

    public function agent()
    {
        return $this->belongsTo(User::class, 'agent_id');
    }
    public function user()
    {
        return $this->belongsTo(User::class, 'action_by');
    }
    public function agentDetails()
    {
        return $this->belongsTo(Agent::class, 'agent_id', 'user_id');
    }

    public function getCommissionAmountAttribute($value)
    {
        return number_format($value, 2);
    }
    public function getCompanyShareAmountAttribute($value)
    {
        return number_format($value, 2);
    }

    public function getCommissionPercentageAttribute($value)
    {
        return number_format($value, 2);
    }

    public function getOrderAmountAttribute($value)
    {
        return number_format($value, 2);
    }
}