<?php

namespace App\Models;

use App\Models\Core\BaseModel;
use App\Models\Core\Status;
use App\Models\Core\Traits\BootTrait;
use App\Models\Core\Traits\CreatedByRelationship;
use App\Models\Patch\Recurring\RecurringCycle;
use Carbon\Carbon;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\Relations\BelongsTo;
use Illuminate\Database\Eloquent\Relations\HasMany;
use Illuminate\Database\Eloquent\SoftDeletes;


class Invoice extends   BaseModel
{
    use BootTrait, HasFactory, SoftDeletes, CreatedByRelationship;


    protected $table = 'invoices';


    protected $primaryKey = 'id';


    protected $fillable = [
        'client_id',
        'currency_id',
        'invoice_number',
        'recurring',
        'unit_id',
        'date',
        'due_date',
        'status_id',
        'recurring_cycle_id',
        'sub_total',
        'discount_type',
        'discount',
        'processing_fee',
        'total',
        'received_amount',
        'due_amount',
        'notes',
        'terms',
        'created_by'
    ];

    protected $casts = [
        'due_amount' => 'double',
    ];

    public function setDateAttribute($value)
    {
        $this->attributes['date'] = (new Carbon($value))->format('y-m-d');
    }

    public function setDueDateAttribute($value)
    {
        $this->attributes['due_date'] = (new Carbon($value))->format('y-m-d');
    }


    public function agent()
    {
        return $this->belongsTo(Agent::class, 'agent_id');
    }

    public function client(): BelongsTo
    {
        return $this->belongsTo(config('patch.client'));
    }



    public function status(): BelongsTo
    {
        return $this->belongsTo(Status::class);
    }


    public function lead(): BelongsTo
    {
        return $this->belongsTo(Leads::class,'lead_id');
    }

    public function property()
    {
        return $this->belongsTo(Property::class, 'property_id');
    }

    public function unit()
    {
        return $this->belongsTo(Unit::class, 'unit_id');
    }
    public function unitBooking()
    {
        return $this->belongsTo(UnitBooking::class, 'unit_id');
    }


    public function recurringCycle(): BelongsTo
    {
        return $this->belongsTo(RecurringCycle::class, 'recurring_cycle_id', 'id');
    }

    public function invoiceDetails(): HasMany
    {
        return $this->hasMany('App\Models\InvoiceItem',);
    }

    public function invoiceItems():HasMany
    {
        return $this->hasMany(InvoiceItem::class);
//        return $this->hasMany('App\Models\InvoiceItem',);

    }

    public function invoiceRecurrings(): HasMany
    {
        return $this->hasMany(InvoiceRecurring::class, 'referance_invoice_id', 'id');
    }

    public function payment_transactions() {
        return $this->hasManyThrough(Transaction::class, InvoiceItem::class,
            'invoice_id', 'invoice_item_id', 'id', 'id')
            ->where('transaction_type',PAYMENT);
    }


    public function waiver_transactions() {
        return $this->hasManyThrough(Transaction::class, InvoiceItem::class,
            'invoice_id', 'invoice_item_id', 'id', 'id')
            ->where('transaction_type',WAIVER);
    }

    public function title_status(): BelongsTo
    {
        return $this->belongsTo(Status::class);
    }
}
