<?php


namespace App\Models;


use App\Models\Core\BaseModel;
use App\Models\Core\Status;
use App\Models\Patch\User\User;
use Carbon\Carbon;
use Carbon\Traits\Creator;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Relations\BelongsTo;

class UnitBooking  extends BaseModel
{

    use HasFactory;

    protected $fillable = [
        'property_id',
        'unit_id',
        'user_id',
        'plan_id',
        'status_id',
        'note',
        'payment_status_id',
        'posting_date',
        'document_date',
        'payment_plan',
        'customer_id',
        'installment_date',
        'agent_commission_value',
        'agent_commission_type',
        'no_of_installments',
        'payment_start_date',
        'reference_number',
        'payment_mode',
        'amount',
        'loan_amount',
        'monthly_payment'

    ];


    public function setPostingDateAttribute($value)
    {
        $this->attributes['posting_date'] = (new Carbon($value))->format('y-m-d');
    }

    public function setDocumentDateAttribute($value)
    {
        $this->attributes['document_date'] = (new Carbon($value))->format('y-m-d');
    }

    public function setInstallmentDateAttribute($value)
    {
        $this->attributes['installment_date'] = (new Carbon($value))->format('y-m-d');
    }

    public function setPaymentStartDateAttribute($value)
    {
        $this->attributes['payment_start_date'] = (new Carbon($value))->format('y-m-d');
    }




    public function property()
    {
        return $this->belongsTo(Property::class, 'property_id');
    }


    public function plan()
    {
        return $this->belongsTo(PaymentPlan::class, 'plan_id');
    }

    public function unit()
    {
        return $this->belongsTo(Unit::class, 'unit_id');
    }

    public function booking()
    {
        return $this->belongsTo(Unit::class, 'unit_id');
    }


    public function customer()
    {
        return $this->belongsTo(User::class, 'customer_id');
    }


    public function agent()
    {
        return $this->belongsTo(Agent::class);
    }

    public function user()
    {
        return $this->belongsTo(User::class,'user_id');
    }

    public function status(): BelongsTo
    {
        return $this->belongsTo(Status::class);
    }

    public function payment_status(): BelongsTo
    {
        return $this->belongsTo(Status::class);
    }

    public function document_status(): BelongsTo
    {
        return $this->belongsTo(Status::class);
    }

}