<?php


namespace App\Services\Core\Property;

use App\Repositories\Core\Property\PropertyRepository;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Log;
use Illuminate\Support\Facades\Validator;
use InvalidArgumentException;
use Exception;

class PropertyService
{

    /**
     * @var $propertyRepository
     */
    protected $propertyRepository;

    /**
     * PropertyService constructor.
     *
     * @param PropertyRepository $propertyRepository
     */
    public function __construct(PropertyRepository $propertyRepository)
    {
        $this->propertyRepository = $propertyRepository;
    }

    /**
     * Get all properties.
     *
     * @return \App\Models\Property
     */
    public function getAll()
    {
        return $this->propertyRepository->getAll();
    }
    /**
     * Get  by id.
     *
     * @param $id
     * @return String
     */
    public function getById($id)
    {
        return $this->propertyRepository->getById($id);
    }

    /**
     * Validate customer data.
     * Store to DB if there are no errors.
     *
     * @param array $data
     * @return String
     */
    public function saveCustomerData($data)
    {
        $validator = Validator::make($data, [
            'first_name' => 'required',
            'last_name' => 'required',
            'id_number' => 'required',
            'kra_pin' => 'required',
            'gender' => 'required',
            'dob' => 'required',
            'email' => 'required',
            'phone' => 'required',
            'box_address' => 'required',
            'location_address' => 'required',
            'bank_name' => 'required',
            'bank_branch' => 'required',
            'account_name' => 'required',
            'account_no' => 'required',
            'currency' => 'required',
            'swift_code' => 'required',
            'bank_slip' => 'required',
            'kin_name' => 'required',
            'kin_id' => 'required',
            'kin_kra_pin' => 'required',
            'kin_gender' => 'required',
            'kin_email' => 'required',
            'kin_phone' => 'required',
            'kin_box_address' => 'required',
            'kin_location_address' => 'required',
        ]);

        if ($validator->fails()) {
            throw new InvalidArgumentException($validator->errors()->first());
        }

        $result = $this->propertyRepository->save($data);

        return $result;
    }


    /**
     * Delete  by id.
     *
     * @param $id
     * @return \App\Models\Property
     */
    public function deleteById($id)
    {
        DB::beginTransaction();

        try {
            $property = $this->propertyRepository->delete($id);

        } catch (Exception $e) {
            DB::rollBack();
            Log::info($e->getMessage());

            throw new InvalidArgumentException('Unable to delete data');
        }

        DB::commit();

        return $property;

    }



}
