import AppFunction from "../../core/helpers/app/AppFunction";
import {PROPERTY_LIST, PROPERTY_UNITS} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';
import {numberWithCurrencySymbol} from "../Helpers/Helpers";

export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],

    data(){

        return{
            tableId: 'admin-units-table',
            rowData: {},
            options: {
                url: PROPERTY_UNITS,
                name: "Admin Property Units",
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    }
                ],
                columns: [

                    {
                        title: 'Project Property',
                        type: 'object',
                        key: 'property',
                        modifier: (property) => {
                            return property ? property.project_name : '-';
                        }
                    },
                    {
                        title: this.$t('unit_floor'),
                        type: 'text',
                        key: 'unit_floor',
                    },

                    {
                        title: this.$t('unit_name'),
                        type: 'text',
                        key: 'unit_name',
                    },
                    {
                        title: this.$t('square_foot'),
                        type: 'text',
                        key: 'square_foot',
                    },
                    {
                        title: 'Unit Type',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit ? unit.unit_type_name : '-';
                        }

                    },

                    {
                        title: 'Unit Price(KES)',
                        type: 'object',
                        key:'sale_amount',
                        modifier: (sale_amount => numberWithCurrencySymbol(sale_amount))

                    },
                    {
                        title: this.$t('status'),
                        type: 'custom-html',
                        key: 'status',
                        isVisible: true,
                        modifier: (value) => {
                            return `<span class="badge badge-${value.class} badge-pill mr-2">${value.translated_name}</span>`
                        }
                    },
                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],
                actions: [

                    {
                        title: this.$t('view'),
                        type: 'view',
                        modifier: () => this.$can("update_taxes"),
                    },
                    {
                        title: this.$t('edit'),
                        type: 'edit',
                        modifier: () => this.$can("update_taxes"),
                    },
                    {
                        title: this.$t('delete'),
                        type: 'delete',
                        modifier: () => this.$can("delete_taxes"),
                    }
                ],
                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'
            },


        }

    },
    computed:{

    },
    methods: {
        afterSuccessFromGetEditData(response) {
            this.formData = response.data;
            this.dataLoaded = true;
        },
        getListAction(rowData, actionObj) {
            this.selectUrl = `${PROPERTY_UNITS}/${rowData.id}`;

            if (actionObj.type === 'edit') {
                this.isModalActive = true;
            }
            else if (actionObj.type === 'delete') {
                this.confirmationModalActive = true;
            }
        },
    },


    mounted() {
    }

}
