import AppFunction from "../../core/helpers/app/AppFunction";
import {AGENT_LEEDS_FETCH, UNITS_RESERVE} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';
import {formatDateToLocal, numberWithCurrencySymbol} from "../Helpers/Helpers";

export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],

    data(){

        return{
            tableId: 'agent-leed-table',
            rowData: {},
            isUnitModalActive: false,
            isCustomerModalActive: false,
            isOfferPaymentModalActive: false,
            options:{
                url: UNITS_RESERVE,
                name: 'Agent Leeds List',
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },

                ],


                columns: [
                    {
                        title: 'Client Name',
                        type: 'text',
                        key: 'client_name',
                    },

                    {
                        title: 'Phone',
                        type: 'text',
                        key: 'phone',
                    },
                    {
                        title: 'Email Address',
                        type: 'text',
                        key: 'email',
                    },

                    {
                        title: 'Unit Name',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit ? unit.unit_name : '-';
                        }

                    },
                    // {
                    //     title: this.$t('status'),
                    //     type: 'custom-html',
                    //     key: 'status',
                    //     isVisible: true,
                    //     modifier: (value) => {
                    //         return `<span class="badge badge-${value.class} badge-pill mr-2">${value.translated_name}</span>`
                    //     }
                    // },

                    {
                        title: 'Unit Price(KES)',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit ? unit.sale_amount: '-';
                        }

                    },

                    {
                        title: 'Booking Amount(Kes)',
                        type: 'text',
                        key: 'amount',
                    },

                    {
                        title: 'Unit Size(m2)',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit ? unit.square_foot: '-';
                        }

                    },

                    {
                        title: 'Agent Name',
                        type: 'object',
                        key: 'user',
                        modifier: (user) => {
                            return user ? user.full_name : '-';
                        }

                    },


                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],

                actions: [
                    {
                        title: this.$t('view'),
                        type: 'view',
                    },

                    {
                        title: 'Make Payment',
                        type: 'offer-create',
                    }
                ],


                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'

            }

        }

    },
    computed:{

    },
    methods:{
        getListAction(rowData, actionObj) {
            this.selectUrl = `${UNITS_RESERVE}/${rowData.id}`
            if(actionObj.type==='offer-create'){
                this.isModalActive = true;
            }
        },
        openModal() {
            this.isModalActive = true;

        },
    },

    mounted() {
    }

}
