import AppFunction from "../../core/helpers/app/AppFunction";
import {COMMISSION_FETCH} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';
import { urlGenerator} from "../Helpers/AxiosHelper";
import {numberWithCurrencySymbol} from "../Helpers/Helpers";


export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins],
    props:{
        props:{
            default: ''
        }
    },
    data(){
        return{
            tableId: 'commission-unit-table',
            rowData: {},
            options:{
                url: `${COMMISSION_FETCH}?payment-status=${this.props.commissionStatus}`,
                name: "Agent Commissions",
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },
                    {
                        title: this.$t("properties"),
                        type: "search-and-select-filter",
                        key: "properties",
                        settings: {
                            url: urlGenerator('properties'),
                            modifire: (item) => {
                                return {id: item.id, value: item.project_name}
                            },
                            per_page: 10,
                            loader: 'app-pre-loader',
                            multiple: true,
                        },
                        permission: true
                    },
                    {
                        title: this.$t("unit_no"),
                        type: "search-and-select-filter",
                        key: "units",
                        settings: {
                            url: urlGenerator(`units?status=11`),
                            modifire: (item) => {
                                return {id: item.id, value: item.unit_name}
                            },
                            per_page: 10,
                            loader: 'app-pre-loader',
                            multiple: true,
                        },
                        permission: this.$can('show_all_data')
                    },
                    {
                        title: 'Agents',
                        type: "search-and-select-filter",
                        key: "agents",
                        settings: {
                            url: urlGenerator('agent-users'),
                            modifire: (item) => {
                                return {id: item.id, value: item.full_name}
                            },
                            per_page: 10,
                            loader: 'app-pre-loader',
                            multiple: true,
                        },
                        permission: this.$can('show_all_data') ? true : false
                    },
                ],

                columns: [
                    {
                        title: 'Project',
                        type: 'object',
                        key: 'property',
                        modifier: (property) => {
                            return property ? property.project_name : '-';
                        }
                    },
                    {
                        title: 'Unit Name',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit? unit.unit_name : '-';
                        }
                    },
                    {
                        title: 'Unit Cost',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit? numberWithCurrencySymbol(unit.sale_amount) : '-';
                        }
                    },
                    {
                        type: 'object',
                        title: 'Total Paid',
                        key: 'invoice',
                        modifier: invoice => {
                            return numberWithCurrencySymbol(invoice?.received_amount) ?? '-' ;
                        }
                    },
                    {
                        type: 'text',
                        title: 'Commission Amount',
                        key: 'commission_amount',
                    },
                    {
                        type: 'text',
                        title: 'Reference No',
                        key: 'reference_no',
                        isVisible:  this.props.commissionStatus === 31
                    },
                    {
                        type: 'text',
                        title: 'Payment Date',
                        key: 'payment_date',
                        isVisible:  this.props.commissionStatus === 31
                    },
                    {
                        title: 'Agent Name',
                        type: 'object',
                        key: 'agent',
                        modifier: (user) => {
                            return user ? `${user.first_name} ${user.last_name}` : '-';
                        }
                    },
                    {
                        title: this.$t('actions'),
                        type: 'action',
                        isVisible: this.$can('create_commission') && this.props.commissionStatus === 30,
                    }

                ],
                actions: [
                    {
                        title: 'Mark as Paid',
                        type: 'paid',
                        modifier: (rowData) => {
                            return (this.$can('create_commission') && this.props.commissionStatus === 30)
                        },
                    },
                ],

                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: Boolean(this.$can('create_commission') && this.props.commissionStatus === 30),
                tableShadow: false,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'

            }

        }
    },
    computed:{
    },
    methods: {
        getListAction(rowData, actionObj) {
            this.selectUrl = `${COMMISSION_FETCH}/${rowData.id}`;
            if (actionObj.type === 'paid') {
                this.openModal();
                //this.confirmationModalActive = true;
            }
        },
        openModal() {
            this.isModalActive = true;
        },
    }

}
