import AppFunction from "../../core/helpers/app/AppFunction";
import {AGENT_LIST, COMPANY_FETCH} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';

export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],

    data(){

        return{
            tableId: 'company-table',
            rowData: {},
            options:{
                url: COMPANY_FETCH,
                name: 'Companies Lists',
                filters: [
                    {
                        title: this.$t('name'),
                        type: 'text',
                        key: 'name',
                    },
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },
                    {
                        title: this.$t('country'),
                        type: 'drop-down-filter',
                        key: 'countries',
                        option: [],
                    }
                ],

                columns: [
                    {
                        title: this.$t('name'),
                        type: 'component',
                        key: 'name',
                        componentName: 'app-table-media',
                    },
                    {
                        title: this.$t('status'),
                        type: 'custom-html',
                        key: 'user',
                        modifier: (user) => {
                            return `<span class="badge badge-${user?.status?.class} badge-pill mr-2">${user?.status?.translated_name}</span>`
                        }
                    },
                    {
                        title: this.$t('country'),
                        type: 'object',
                        key: 'country',
                        modifier: (value) => {
                            return value ? value.name : '-';
                        }
                    },
                    {
                        title: "Account Name",
                        type: 'text',
                        key: 'account_name',
                    },
                    {
                        title: "Contact ",
                        type: 'text',
                        key: 'phone',
                    },
                    {
                        title: "Postal Code",
                        type: 'text',
                        key: 'postal_code',
                    },
                    {
                        title: "KRA Pin",
                        type: 'text',
                        key: 'kra_pin',
                    },


                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],
                actions: [
                    {
                        title: this.$t('edit'),
                        type: 'edit',
                        modifier: () => this.$can("update_agents"),
                    },
                    {
                        title: this.$t('delete'),
                        type: 'delete',
                        modifier: () => this.$can("delete_agents"),
                    }
                ],

                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'

            }

        }

    },
    computed:{

    },
    methods:{
        getListAction(rowData, actionObj) {
            this.selectUrl = `${COMPANY_FETCH}/${rowData.id}`;
            if (actionObj.type === 'view') {
                location.replace(AppFunction.getAppUrl(`/${COMPANY_FETCH }/${rowData.id}/details`));
            } else if (actionObj.type === 'active') {
                this.changeUserStatus(1, rowData.user);
            } else if (actionObj.type === 'de_activate') {
                this.changeUserStatus(2, rowData.user);
            } else if (actionObj.type === 'edit') {
                this.isModalActive = true;
            } else if (actionObj.type === 'delete') {
                this.confirmationModalActive = true;
            }
        },

        viewCompanyDetails() {
            location.replace(AppFunction.getAppUrl('/company-details'));
        },
        getTableMediaAction() {
            this.$hub.$on('getTableMediaAction', (data) => {
                this.viewCompanyDetails();
            })
        },
        openModal() {
            this.isModalActive = true;
        },
        changeUserStatus(status, userInfo) {
            let url = `${actions.USERS_LIST}/${userInfo.id}`,
                reqData = userInfo;
            reqData.status_id = status;
            this.axiosPatch({
                url: url,
                data: reqData
            }).then(res => {
                this.$toastr.s(res.data.message);
            }).catch(error => {
                let {message} = error.response.data;
                this.$toastr.e(message);
            }).finally(() => {
                this.$hub.$emit('reload-' + this.tableId);
            });
        }

    },

    mounted() {
        this.getTableMediaAction();

    }

}
