import {KYC_DOCUMENTS} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import { urlGenerator} from "../Helpers/AxiosHelper";
import {formatDateForServer} from "../Helpers/DateTimeHelper";


export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],
    props: {
        props: {
            default: ''
        }
    },
    data(){

        return{
            tableId: 'titles-table',
            rowData: {},
            options:{
                url:  this.props.userType ==='AGENT'? KYC_DOCUMENTS + '/agent/'+ this.props.clientId : KYC_DOCUMENTS + '/client/' + this.props.clientId ,
                name: "TITLE DEEDS",
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },

                ],

                columns: [
                    {
                        title: "Attachment",
                        type: 'custom-html',
                        key: 'attachment',
                        modifier: (file) => {
                            return file ? `<a onclick="window.open(this.href,'_blank');return false;" href="${urlGenerator(file.path)}"> <i data-feather="external-link"/></a>` : '-';
                        }
                    },
                    {
                        title: "Document Type",
                        type: 'text',
                        key: 'name',
                    },
                    {
                        title: 'Uploaded By',
                        type: 'object',
                        key: 'user',
                        modifier: (user) => {
                            return user ? user.full_name : '-';
                        }
                    },
                    {
                        title: "Uploaded On",
                        type: 'text',
                        key: 'updated_at',
                        modifier: (updated_at) => {
                            return formatDateForServer(updated_at);
                        }
                    },

                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],
                actions: [

                    {
                        title: this.$t('edit'),
                        type: 'edit',
                        modifier: () => this.$can("view_properties"),
                    },
                    {
                        title: this.$t('delete'),
                        type: 'delete',
                        modifier: () => this.$can("view_properties"),
                    }
                ],

                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: false,
                showSearch: false,
                showAction: true,
                tableShadow: false,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'


            }

        }

    },
    computed:{
    },
    methods: {
        getListAction(rowData, actionObj) {
            this.selectUrl = `${KYC_DOCUMENTS}/${rowData.id}`;
            if (actionObj.type === 'edit') {
                this.isModalActive = true;
            } else if (actionObj.type === 'delete') {
                this.confirmationModalActive = true;
            }
        },
    }

}
