import AppFunction from "../../core/helpers/app/AppFunction";
import {PROJECT_DOCUMENTS_FETCH} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';
import { urlGenerator} from "../Helpers/AxiosHelper";


export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],
    props:{
        props:{
            default: ''
        }
    },
    data(){
        return{
            tableId: 'documents-table',
            rowData: {},
            options:{
                url: `${PROJECT_DOCUMENTS_FETCH}?properties=${this.props.propertyId}`,
                name: "Project-Document-Table",
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },

                ],

                columns: [
                    {
                        title: "Name",
                        type: 'text',
                        key: 'name',
                    },
                    {
                        title: "Document Category",
                        type: 'text',
                        key: 'category',
                    },


                    {
                        title: "Attachment",
                        type: 'custom-html',
                        key: 'attachment',
                        modifier: (file) => {
                            return file ? `<a onclick="window.open(this.href,'_blank');return false;" href="${urlGenerator(file.path)}"> <i data-feather="external-link"/></a>` : '-';
                        }
                    },
                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],
                actions: [

                    {
                        title: this.$t('edit'),
                        type: 'edit',
                        modifier: () => this.$can("update_document"),
                    },
                    {
                        title: this.$t('delete'),
                        type: 'delete',
                        modifier: () => this.$can("delete_document"),
                    }
                ],

                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: false,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'

            }

        }

    },
    computed:{
    },
    methods: {
        getListAction(rowData, actionObj) {
            this.selectUrl=`${PROJECT_DOCUMENTS_FETCH}/${rowData.id}`;
            if (actionObj.type === 'edit') {
                this.isModalActive = true;
            } else if (actionObj.type === 'delete') {
                this.confirmationModalActive = true;
            }
        },

        openModal() {
            this.isModalActive = true;
        },
    }

}
