import AppFunction from "../../core/helpers/app/AppFunction";
import {PROPERTY_LIST} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';
import {formatDateToLocal, numberWithCurrencySymbol} from "../Helpers/Helpers";

export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],

    data(){

        return{
            tableId: 'properties-table',
            rowData: {},
            options:{
                url: PROPERTY_LIST,
                name: this.$t('properties-table'),
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },
                ],
                columns: [
                    {
                        title: this.$t('project_name'),
                        type: 'text',
                        key: 'project_name',
                    },
                    {
                        title: this.$t('property_name'),
                        type: 'text',
                        key: 'property_name',
                    },
                    {
                        title: this.$t('business_code'),
                        type: 'text',
                        key: 'business_code',
                    },
                    {
                        title: this.$t('project_code'),
                        type: 'text',
                        key: 'project_code',
                    },

                    {
                        title: this.$t('location'),
                        type: 'text',
                        key: 'location',
                    },  {
                        title: this.$t('country'),
                        type: 'text',
                        key: 'country',
                    },
                    {
                        title: this.$t('city'),
                        type: 'text',
                        key: 'city',
                    },


                    {
                        title: this.$t('unit_no'),
                        type: 'text',
                        key: 'unit_no',
                    },  {
                        title: this.$t('posting_date'),
                        type: 'text',
                        key: 'posting_date',
                        modifier: (posting_date => formatDateToLocal(posting_date))

                    },

                    {
                        title: this.$t('document_date'),
                        type: 'text',
                        key: 'document_date',
                        modifier: (document_date=> formatDateToLocal(document_date))

                    },


                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],


                actions: [
                    {
                        title: this.$t('view'),
                        type: 'view',
                        // modifier: () => this.$can("view_property_details"),
                    },
                    {
                        title: this.$t('edit'),
                        type: 'edit',
                        modifier: () => this.$can("update_properties"),
                    },
                    {
                        title: this.$t('delete'),
                        type: 'delete',
                        modifier: () => this.$can("delete_properties"),
                    }
                ],

                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'

            },
            isProductTypeAddEditModalActive: false,


        }

    },
    computed:{

    },
    methods:{
        getListAction(rowData, actionObj) {
            this.selectUrl = `${PROPERTY_LIST}/${rowData.id}`;
            if (actionObj.type === 'view') {
                location.replace(AppFunction.getAppUrl(`/${PROPERTY_LIST}/${rowData.id}/details`));
            }
           else if (actionObj.type === 'edit') {
                this.isModalActive = true;
            }
           else if (actionObj.type === 'delete') {
                    this.confirmationModalActive = true;
            }
        },

        viewPropertyDetails() {
            location.replace(AppFunction.getAppUrl('/property-details'));
        },
        getTableMediaAction() {
            this.$hub.$on('getTableMediaAction', (data) => {
                this.viewPropertyDetails();
            })
        },

    },

    mounted() {
        this.getTableMediaAction();

    }

}
