import AppFunction from "../../core/helpers/app/AppFunction";
import {PROSPECT_UNITS} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';
import {numberWithCurrencySymbol} from "../Helpers/Helpers";

export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],

    data(){

        return{
            tableId: 'reserved-unit-payments',
            rowData: {},
            options:{
                url: PROSPECT_UNITS,
                name: 'Reserved Unit Payments',
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },
                ],

                columns: [
                    {
                        title: 'Client Name',
                        type: 'text',
                        key: 'client_name',
                    },

                    {
                        title: 'Phone',
                        type: 'text',
                        key: 'phone',
                    },
                    {
                        title: 'Email Address',
                        type: 'text',
                        key: 'email',
                    },

                    {
                        title: 'Unit Name',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit ? unit.unit_name : '-';
                        }

                    },


                    {
                        title: 'Unit Price(KES)',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit && unit.sale_amount ? numberWithCurrencySymbol(unit.sale_amount) : '-';

                        }
                    },


                    {
                        title: this.$t('status'),
                        type: 'custom-html',
                        key: 'status',
                        isVisible: true,
                        modifier: (value) => {
                            return `<span class="badge badge-${value.class} badge-pill mr-2">${value.translated_name}</span>`
                        }
                    },

                    {
                        title: 'Agent Name',
                        type: 'object',
                        key: 'user',
                        modifier: (user) => {
                            return user ? user.full_name : '-';
                        }

                    },


                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],
                actions: [


                    {
                        title: 'Make Payment',
                        type: 'offer-create',
                    },
                    {
                        title: 'Mark as Lost',
                        type: 'active',
                        modifier: (rowData) => {
                            return rowData.status?.name
                        },
                    },
                ],

                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'


            }

        }

    },
    computed:{

    },
    methods:{
        getListAction(rowData, actionObj) {
            this.selectUrl = `${PROSPECT_UNITS}/${rowData.id}`
            if (actionObj.type === 'active') {
                this.changePaymentStatus(19, rowData.id);
            }
            else   if(actionObj.type==='offer-create'){
                this.isModalActive = true;
            }
        },
        openModal() {
            this.isModalActive = true;
        },

        changePaymentStatus(status, unitInfo) {
            let url = `${actions.PROSPECT_UNITS}/${unitInfo}`,
            reqData = { status_id: status };
            this.axiosPatch({
                url: url,
                data: reqData
            }).then(res => {
                this.$toastr.s(res.data.message);
            }).catch(error => {
                let {message} = error.response.data;
                this.$toastr.e(message);
            }).finally(() => {
                this.$hub.$emit('reload-' + this.tableId);
            });
        }

    },

    mounted() {
    }

}
