import AppFunction from "../../core/helpers/app/AppFunction";
import {PROJECT_UNITS_BOOKING_FETCH} from "../Config/PatchApiUrls";
import {FormMixin} from "../../core/mixins/form/FormMixin";
import {DeleteMixins, ModalMixins} from "./patch/DeleteMixins";
import {countries} from "./patch/FilterMixins";
import {mapGetters} from "vuex";
import * as actions from '../Config/ApiUrl';
import { urlGenerator} from "../Helpers/AxiosHelper";
import {numberWithCurrencySymbol} from "../Helpers/Helpers";


export default {
    mixins: [FormMixin, DeleteMixins, ModalMixins, countries],
    data(){
        return{
            tableId: 'project-unit-table',
            rowData: {},
            options:{
                url: PROJECT_UNITS_BOOKING_FETCH,
                name: "Project Units",
                filters: [
                    {
                        'title': this.$t('created'),
                        'type': 'range-picker',
                        'key': 'date',
                        'option': ['today', 'thisMonth', 'last7Days', 'nextYear']
                    },

                ],

                columns: [
                    {
                        title: 'Project',
                        type: 'object',
                        key: 'property',
                        modifier: (property) => {
                            return property ? property.project_name : '-';
                        }
                    },

                    {
                        title: 'Unit Name',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit? unit.unit_name : '-';
                        }
                    },
                    {
                        title: 'Unit Floor Number',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit? unit.unit_floor : '-';
                        }
                    },

                    {
                        title: 'Sold By (Agent)',
                        type: 'object',
                        key: 'user',
                        modifier: (user) => {
                            return user ? user.full_name : '-';
                        }
                    },


                    {
                        title: 'Customer',
                        type: 'object',
                        key: 'customer',
                        modifier: (user) => {
                            // return user ? `${user.first_name} ${user.last_name}` : '-';

                            return user ? user.full_name : '-';
                        }
                    },

                    {
                        title: 'Unit Payment Plan',
                        type: 'object',
                        key: 'plan',
                        modifier: (plan) => {
                            return plan? plan.name : '-';
                        }
                    },

                    // {
                    //     title: 'Unit Payment Deposit(%)',
                    //     type: 'object',
                    //     key: 'plan',
                    //     modifier: (plan) => {
                    //         return plan? plan.deposit_percentage: '-';
                    //     }
                    // },
                    //
                    // {
                    //     title: 'Unit Payment Balance(%)',
                    //     type: 'object',
                    //     key: 'plan',
                    //     modifier: (plan) => {
                    //         return plan? plan.balance_percentage: '-';
                    //     }
                    // },



                    {
                        title: 'Unit Cost (KES)',
                        type: 'object',
                        key: 'unit',
                        modifier: (unit) => {
                            return unit && unit.sale_amount ? numberWithCurrencySymbol(unit.sale_amount) : '-';

                        }
                    },

                    {
                        title: this.$t('actions'),
                        type: 'action'
                    }
                ],

                actions: [
                    {
                        title: this.$t('view'),
                        type: 'view',
                    }
                ],


                rowLimit: 10,
                orderBy: 'desc',
                responsive: true,
                showHeader: true,
                showFilter: true,
                showSearch: true,
                showAction: true,
                tableShadow: true,
                actionType: 'dropdown',
                datatableWrapper: true,
                paginationType: 'pagination'

            }

        }
    },
    computed:{
    },
    methods: {
        getListAction(rowData, actionObj) {
            this.selectUrl = `${PROJECT_UNITS_BOOKING_FETCH}/${rowData.id}`;
            if (actionObj.type === 'view') {
                location.replace(AppFunction.getAppUrl(`unit/sold/${rowData.id}/details`));
            }

        },
        openModal() {
            this.isModalActive = true;
        },
    }

}
